
**************************************************************************************
* Code for "Gender Differences and Dynamics in Competition: The Role of Luck"
* by Gill, David, and Prowse, Victoria
* Published in Quantitative Economics, 2014, vol. 5(2), pp 351376
**************************************************************************************

**************************************************************************************
* Load data
**************************************************************************************

capture log close
clear
set memory 600m
set more off

global data  "C:\victoriasfiles\Experinment\QE_DataAppendix"
global Reps 1000

use $data\GenderLuckData.dta,clear

**************************************************************************************
* Generate varaibles
**************************************************************************************

ge i=prize*OtherEffort
ge RU2=RU^2
sort Sub Period
ge RUprize=RU*prize
ge RU2prize=RU^2*prize
ge OtherEffortprize=OtherEffort*prize
ge OtherEffort2=OtherEffort^2
ge OtherEffortRU=OtherEffort*RU
ge WinnerPrize=Winner*prize
ge WinnerPrizemale=Winner*prize*Male
ge Winnermale=Winner*Male
ge RUmale=RU*Male
ge RU2male=RU2*Male
ge RUprizemale=RUprize*Male
ge prizemale=prize*Male
ge RU2prizemale=RU*prize*Male
ge prize2=prize^2
ge prize2male=prize2*Male
drop TT1 TT2
ge Loserv=prize*(1-Winner)
ge Loservmale=Loserv*Male
ge RUprize2=RU*prize^2
ge RUprize2male=RU*prize^2*Male
ge RU_hi=1 if RU>.8
replace RU_hi=0 if RU_hi==.
ge RU_himale=RU_hi*Male
ge RU_lo=1 if RU<.2
replace RU_lo=0 if RU_lo==.
ge RU_lomale=RU_lo*Male
ge prizeP=_n
replace prizeP=. if prizeP>39
replace prizeP=prizeP/10
ge OtherEffortmale=OtherEffort*Male
ta Period, gen(TTM)
drop TTM1-TTM2
replace TTM3=0 if Male==0
replace TTM4=0 if Male==0
replace TTM5=0 if Male==0
replace TTM6=0 if Male==0
replace TTM7=0 if Male==0
replace TTM8=0 if Male==0
replace TTM9=0 if Male==0
replace TTM10=0 if Male==0
drop TT10 TTM10
ge RUfemale=RU*(1-Male)
ge RUprizefemale=RUprize*(1-Male)
ta Period, gen(TTF)
drop TTF1-TTF2
replace TTF3=0 if Male==1
replace TTF4=0 if Male==1
replace TTF5=0 if Male==1
replace TTF6=0 if Male==1
replace TTF7=0 if Male==1
replace TTF8=0 if Male==1
replace TTF9=0 if Male==1
replace TTF10=0 if Male==1
drop TTF10
ge Effortmale=Effort*Male
ge Loser=1-Winner
ge Losermale=Loser*Male
ge j=l.Winner*prize
ge jmale=l.Winner*prizemale
ge Female=1-Male
ge prizefemale=prize*Female
ge Loserfemale=Loser*Female
ge WinnerPrizefemale=WinnerPrize*Female
ge Loservfemale=Loserv*Female
ge WinnerPrizefemale2=WinnerPrizefemale^2
ge Loservmale2=Loservmale^2
ge DWinnermale=Male*(Prob/100)*Winner
ge DWinnerfemale=Female*(Prob/100)*Winner
ge Dfemale=Winner*prize*(1-Prob/100)*Female
ge Dmale=Winner*prize*(1-Prob/100)*Male
ge DLfemale=(1-Winner)*prize*(1-Prob/100)*Female
ge DLmale=(1-Winner)*prize*(1-Prob/100)*Male

save "$data\GenderLuckData_var.dta",replace

*************************************************************************************
* Section 3, Figure 2
*Kernal density of effort for men and women
*************************************************************************************

use "$data\GenderLuckData_var.dta",clear

table Period Male if Type==2, contents(mean Effort) format(%-12.2f)
kdensity Effort if Male==1 & Type==2 & Period>2, /*
*/ lcolor(black) addplot((kdensity Effort if Type==2 & Male==0 & Period>2, /*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ aspectratio(.4)/*
*/ title(" ") /*
*/ lcolor(black) lpattern(dash))) legend(on order(1 "Men" 2 "Women") cols(2) region(lpattern(blank)))

kdensity Effort if Male==1 & Type==2 & Period>5, /*
*/ lcolor(black) addplot((kdensity Effort if Type==2 & Male==0 & Period>5, /*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ aspectratio(.4)/*
*/ title(" ") /*
*/ lcolor(black) lpattern(dash))) legend(on order(1 "Men" 2 "Women") cols(2) region(lpattern(blank)))

*************************************************************************************
* Section 3
* KS/Rank sum tests 
*************************************************************************************

* aggregate by subject
bys Subject: egen mEffort=mean(Effort) if Period>2

* first mover
ksmirnov mEffort if Type==1 & Period==3, by(Male) exact
ranksum mEffort if Type==1 & Period==3, by(Male) 

* second mover
ksmirnov mEffort if Type==2 & Period==3, by(Male) exact
ranksum mEffort if Type==2 & Period==3, by(Male) 


***********************************************************************************************
* Section 3 In text stats
* Test for equality of means and variances
***********************************************************************************************

* Restricted
xtmixed Effort || Subject: if Period>2 & Type==2,mle
* Unrestricted male
xtmixed Effort || Subject: if Period>2 & Type==2 & Male==1,mle
* Unrestricted female
xtmixed Effort || Subject: if Period>2 & Type==2 & Male==0,mle

* Restricted
xtmixed Effort || Subject: if Period>5 & Type==2,mle
* Unrestricted male
xtmixed Effort || Subject: if Period>5 & Type==2 & Male==1,mle
* Unrestricted female
xtmixed Effort || Subject: if Period>5 & Type==2 & Male==0,mle


*************************************************************************************
*BS Test quantiles - Period>2 (Table 1, Rounds 3-10)
*************************************************************************************

use "$data\GenderLuckData_var.dta",clear

save "$data\bsdata.dta", replace
clear
ge nn=1
save "$data\bs_desc.dta",replace
forvalues w=1(1)$Reps{
qui use "$data\bsdata.dta", clear
qui drop if Period<3
qui keep if Type==2
qui keep if Male==1
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui save "$data\male.dta",replace
qui use "$data\bsdata.dta", clear
qui drop if Period<3
qui keep if Type==2
qui keep if Male==0
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui replace SubBS=SubBS+100
qui append using "$data\male.dta"
qui sort SubBS Period
qui tsset SubBS Period
qui _pctile  Effort if Period>2 & Type==2,  percentiles(20 40 45 50 55 60 80) altdef
qui ge P20=r(r1)
qui ge P40=r(r2)
qui ge P45=r(r3)
qui ge P50=r(r4)
qui ge P55=r(r5)
qui ge P60=r(r6)
qui ge P80=r(r7)
qui ge Q_20=1 if Effort<=P20
qui replace Q_20=0 if Q_20==.
qui ge Q_40=1 if Effort<=P40
qui replace Q_40=0 if Q_40==.
qui ge Q_45=1 if Effort<=P45
qui replace Q_45=0 if Q_45==.
qui ge Q_50=1 if Effort<=P50
qui replace Q_50=0 if Q_50==.
qui ge Q_55=1 if Effort<=P55
qui replace Q_55=0 if Q_55==.
qui ge Q_60=1 if Effort<=P60
qui replace Q_60=0 if Q_60==.
qui ge Q_80=1 if Effort<=P80
qui replace Q_80=0 if Q_80==.
qui replace Q_20=. if (Period<3 | Type==1)
qui replace Q_40=. if (Period<3 | Type==1)
qui replace Q_45=. if (Period<3 | Type==1)
qui replace Q_50=. if (Period<3 | Type==1)
qui replace Q_55=. if (Period<3 | Type==1)
qui qui replace Q_60=. if (Period<3 | Type==1)
qui replace Q_80=. if (Period<3 | Type==1)
qui bys Male:egen M20=mean(Q_20)
qui bys Male:egen M40=mean(Q_40)
qui bys Male:egen M45=mean(Q_45)
qui bys Male:egen M50=mean(Q_50)
qui bys Male:egen M55=mean(Q_55)
qui bys Male:egen M60=mean(Q_60)
qui bys Male:egen M80=mean(Q_80)
qui bys Male: gen nn=_n
qui keep if nn==1
qui keep Male M20-M80
qui qui sort Male
qui ge id=`w'
qui append using "$data\bs_desc.dta"
qui save "$data\bs_desc.dta", replace
}

sort id Male
foreach w of numlist 20 40 45 50 55 60 80{
qui ge M`w'_W=M`w'[_n-1]
replace M`w'_W=. if Male==0
}
drop if Male==0
foreach w of numlist 20 40 45 50 55 60 80{
qui  ge DM`w'=M`w'-M`w'_W
}
su  M20- M80  M20_W M40_W M45_W M50_W M55_W M60_W M80_W DM20 DM40 DM45 DM50 DM55 DM60 DM80, sep(25)

*************************************************************************************
* BS Test quantiles - (Table 1, Rounds 6-10)
*************************************************************************************

use "$data\GenderLuckData_var.dta",clear

save "$data\bsdata.dta", replace
clear
ge nn=1
save "$data\bs_desc1.dta",replace
forvalues w=1(1)$Reps{
qui  use "$data\bsdata.dta", clear
qui keep if Type==2
qui  keep if Male==1
qui  drop if Period<6
qui  bsample,  cluster(Sub) idcluster(SubBS) 
qui  save "$data\male.dta",replace
qui use "$data\bsdata.dta", clear
qui drop if Period<6
qui keep if Type==2
qui keep if Male==0
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui replace SubBS=SubBS+100
qui append using "$data\male.dta"
qui sort SubBS Period
qui tsset SubBS Period
qui _pctile  Effort if Period>2 & Type==2,  percentiles(20 40 45 50 55 60 80)
qui ge P20=r(r1)
qui ge P40=r(r2)
qui ge P45=r(r3)
qui ge P50=r(r4)
qui ge P55=r(r5)
qui ge P60=r(r6)
qui ge P80=r(r7)
qui ge Q_20=1 if Effort<=P20
qui replace Q_20=0 if Q_20==.
qui ge Q_40=1 if Effort<=P40
qui replace Q_40=0 if Q_40==.
qui ge Q_45=1 if Effort<=P45
qui replace Q_45=0 if Q_45==.
qui ge Q_50=1 if Effort<=P50
qui replace Q_50=0 if Q_50==.
qui ge Q_55=1 if Effort<=P55
qui replace Q_55=0 if Q_55==.
qui ge Q_60=1 if Effort<=P60
qui replace Q_60=0 if Q_60==.
qui ge Q_80=1 if Effort<=P80
qui replace Q_80=0 if Q_80==.
qui replace Q_20=. if (Period<3 | Type==1)
qui replace Q_40=. if (Period<3 | Type==1)
qui replace Q_45=. if (Period<3 | Type==1)
qui replace Q_50=. if (Period<3 | Type==1)
qui replace Q_55=. if (Period<3 | Type==1)
qui replace Q_60=. if (Period<3 | Type==1)
qui replace Q_80=. if (Period<3 | Type==1)
qui bys Male:egen M20=mean(Q_20)
qui bys Male:egen M40=mean(Q_40)
qui bys Male:egen M45=mean(Q_45)
qui bys Male:egen M50=mean(Q_50)
qui bys Male:egen M55=mean(Q_55)
qui bys Male:egen M60=mean(Q_60)
qui bys Male:egen M80=mean(Q_80)
qui bys Male: gen nn=_n
qui keep if nn==1
qui keep Male M20-M80
qui sort Male
qui ge id=`w'
qui append using "$data\bs_desc1.dta"
qui save "$data\bs_desc1.dta", replace
}
sort id Male
foreach w of numlist 20 40 45 50 55 60 80{
qui ge M`w'_W=M`w'[_n-1]
replace M`w'_W=. if Male==0
}
drop if Male==0
foreach w of numlist 20 40 45 50 55 60 80{
qui ge DM`w'=M`w'-M`w'_W
}
su  M20- M80  M20_W M40_W M45_W M50_W M55_W M60_W M80_W DM20 DM40 DM45 DM50 DM55 DM60 DM80, sep(25)


***********************************************************************************************
* Section 3 Figure 3
* Male and Female effort round by round
***********************************************************************************************

use "$data\GenderLuckData_var.dta",clear
bys Period Male: egen mEffort=mean(Effort)
ge EffortM=Effort
replace EffortM=. if Male==0
ge EffortF=Effort
replace EffortF=. if Male==1

ge Period1=Period
replace Period1=Period1*3
replace Period1=Period1+1 if Male==0
twoway (bar mEffort Period1 if Male==1) (bar mEffort Period1 if Male==0) , /*
*/ aspectratio(.3)/*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ ytitle("Effort",size(medsmall))/*
*/ xtitle("Round", size(medsmall))/*
*/ ylabel(15(5)30)/*
*/ xlabel(3.5 "1" 6.5 "2" 9.5 "3" 12.5 "4" 15.5 "5" 18.5 "6" 21.5 "7" 24.5 "8" 27.5 "9" 30.5 "10",noticks)/*
*/ xtick()/*
*/ legend(label(1 "Men") label(2 "Women") size(medsmall)) 
drop Period1


***********************************************************************************************
* Section 4.2 Table 2
* Pref Spec: Joint model for men and women - 2nd Movers
***********************************************************************************************

use "$data\GenderLuckData_var.dta",clear

* second mover
xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es2_mf
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale

xtabond2 Effort Male prize prizemale TTM* TTF* l(1/2).Loser l(1/2).Losermale l(1/2).WinnerPrize l(1/2).WinnerPrizemale l(1/2).Loserv l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
est store es2

* Bootstrap variance decomp results - Pref. spec. 2nd movers

clear
ge nn=1
save "$data\bsresults.dta",replace

forvalues w=1(1)$Reps{

qui use "$data\bsdata.dta", clear
qui keep if Type==2
qui keep if Male==1
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui save "$data\male.dta",replace

qui use "$data\bsdata.dta", clear
qui keep if Type==2
qui keep if Male==0
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui replace SubBS=SubBS+100

append using "$data\male.dta"

qui sort SubBS Period
qui tsset SubBS Period

qui xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(SubBS)

qui predict phat
qui replace phat=. if Period<3
qui ge e=Effort
qui replace e=. if Period<3
qui bys SubBS: egen me=mean(e)
qui bys SubBS: egen mphat=mean(phat)
qui ge alpha=me-mphat
* Predication including individual effect
qui replace phat=phat+alpha
qui egen TSS_P=sd(e)
qui replace TSS_P=TSS_P^2
qui egen ESS_P=sd(phat)
qui replace ESS_P=ESS_P^2
qui gen R2_P=ESS_P/TSS_P
qui egen TSS_PFj=sd(e) if Male==0
qui egen TSS_PF=max(TSS_PFj)
qui replace TSS_PF=TSS_PF^2
qui egen ESS_PFj=sd(phat) if Male==0
qui egen ESS_PF=max(ESS_PFj)
qui replace ESS_PF=ESS_PF^2
qui gen R2_PF=ESS_PF/TSS_PF

qui egen TSS_PMj=sd(e) if Male==1
qui egen TSS_PM=max(TSS_PMj)
qui replace TSS_PM=TSS_PM^2
qui egen ESS_PMj=sd(phat) if Male==1
qui egen ESS_PM=max(ESS_PMj)
qui replace ESS_PM=ESS_PM^2
qui gen R2_PM=ESS_PM/TSS_PM
qui drop  phat- alpha 
qui sort SubBS Period

* With level equation (2 lags)
qui xtabond2 Effort  Male prize prizemale TTM* TTF*  if Type==2 & Period>2, ivstyle(prize prizemale TTM* TTF*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(SubBS)


qui predict phat
qui replace phat=. if Period<3
qui ge e=Effort
qui replace e=. if Period<3
qui bys SubBS: egen me=mean(e)
qui bys SubBS: egen mphat=mean(phat)
qui ge alpha=me-mphat
qui replace phat=phat+alpha
qui egen TSS_R=sd(e)
qui replace TSS_R=TSS_R^2
qui egen ESS_R=sd(phat)
qui replace ESS_R=ESS_R^2
qui gen R2_R=ESS_R/TSS_R
qui egen TSS_RFj=sd(e) if Male==0
qui egen TSS_RF=max(TSS_RFj)
qui replace TSS_RF=TSS_RF^2
qui egen ESS_RFj=sd(phat) if Male==0
qui egen ESS_RF=max(ESS_RFj)
qui replace ESS_RF=ESS_RF^2
qui gen R2_RF=ESS_RF/TSS_RF
qui egen TSS_RMj=sd(e) if Male==1
qui egen TSS_RM=max(TSS_RMj)
qui replace TSS_RM=TSS_RM^2
qui egen ESS_RMj=sd(phat) if Male==1
qui egen ESS_RM=max(ESS_RMj)
qui replace ESS_RM=ESS_RM^2
qui gen R2_RM=ESS_RM/TSS_RM
qui drop  phat- alpha 

qui ge PartialM= R2_PM- R2_RM
qui ge PartialF= R2_PF- R2_RF
qui ge DPartial=(R2_PF-R2_RF)-(R2_PM-R2_RM)

qui ge nn=_n
qui keep if nn==1
qui keep R2*
qui ge PartialM= R2_PM- R2_RM
qui ge PartialF= R2_PF- R2_RF
qui ge DPartial=(R2_PF-R2_RF)-(R2_PM-R2_RM)
qui ge Partial= R2_P- R2_R
qui append using "$data\bsresults.dta" 
qui save "$data\bsresults.dta", replace
}

su

***********************************************************************************************
* Section 4.2 Table 2
* Robustness to winnings being defined relative to expected winnings (instead of absolute winnings as in the preferred specification)
***********************************************************************************************

use "$data\GenderLuckData_var.dta",clear

xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).(Dfemale Dmale DLfemale DLmale) if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale
estimates store es2_mf_r2

ge Dboth=Dmale+Dfemale
ge DLboth=DLmale+DLfemale

* Robustness to winnings being defined relative to expected winnings (instead of absolute winnings as in the preferred specification)
xtabond2 Effort  Male prize prizemale TTM* TTF* l(1/2).Loser l(1/2).Losermale l(1/2).(Dboth Dmale DLboth DLmale) if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es2_mf_r2t
drop Dboth DLboth

***********************************************************************************************
* Bootstrap variance results for winnings and losses relative to expectations
***********************************************************************************************

* 2nd movers
clear
ge nn=1
save "$data\bsresults_r.dta",replace

forvalues w=1(1)$Reps{

qui use "$data\bsdata.dta", clear
qui keep if Type==2
qui keep if Male==1
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui save "$data\male.dta",replace

qui use "$data\bsdata.dta", clear
qui keep if Type==2
qui keep if Male==0
qui bsample,  cluster(Sub) idcluster(SubBS) 
qui replace SubBS=SubBS+100

qui append using "$data\male.dta"

qui sort SubBS Period
qui tsset SubBS Period

* Robustness to winnings being defined relative to expected winnings (instead of absolute winnings as in the preferred specification)
qui xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).(Dfemale Dmale DLfemale DLmale) if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(SubBS)

qui predict phat
qui replace phat=. if Period<3
qui ge e=Effort
qui replace e=. if Period<3
qui bys SubBS: egen me=mean(e)
qui bys SubBS: egen mphat=mean(phat)
qui ge alpha=me-mphat
* Predication including individual effect
qui replace phat=phat+alpha
qui egen TSS_P=sd(e)
qui replace TSS_P=TSS_P^2
qui egen ESS_P=sd(phat)
qui replace ESS_P=ESS_P^2
qui gen R2_P=ESS_P/TSS_P
qui egen TSS_PFj=sd(e) if Male==0
qui egen TSS_PF=max(TSS_PFj)
qui replace TSS_PF=TSS_PF^2
qui egen ESS_PFj=sd(phat) if Male==0
qui egen ESS_PF=max(ESS_PFj)
qui replace ESS_PF=ESS_PF^2
qui gen R2_PF=ESS_PF/TSS_PF

qui egen TSS_PMj=sd(e) if Male==1
qui egen TSS_PM=max(TSS_PMj)
qui replace TSS_PM=TSS_PM^2
qui egen ESS_PMj=sd(phat) if Male==1
qui egen ESS_PM=max(ESS_PMj)
qui replace ESS_PM=ESS_PM^2
qui gen R2_PM=ESS_PM/TSS_PM
qui drop  phat- alpha 
qui sort SubBS Period

* With level equation (2 lags)
qui xtabond2 Effort  Male prize prizemale TTM* TTF*  if Type==2 & Period>2, ivstyle(prize prizemale TTM* TTF*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(SubBS)

qui predict phat
qui replace phat=. if Period<3
qui ge e=Effort
qui replace e=. if Period<3
qui bys SubBS: egen me=mean(e)
qui bys SubBS: egen mphat=mean(phat)
qui ge alpha=me-mphat
qui replace phat=phat+alpha
qui egen TSS_R=sd(e)
qui replace TSS_R=TSS_R^2
qui egen ESS_R=sd(phat)
qui replace ESS_R=ESS_R^2
qui gen R2_R=ESS_R/TSS_R
qui egen TSS_RFj=sd(e) if Male==0
qui egen TSS_RF=max(TSS_RFj)
qui replace TSS_RF=TSS_RF^2
qui egen ESS_RFj=sd(phat) if Male==0
qui egen ESS_RF=max(ESS_RFj)
qui replace ESS_RF=ESS_RF^2
qui gen R2_RF=ESS_RF/TSS_RF
qui egen TSS_RMj=sd(e) if Male==1
qui egen TSS_RM=max(TSS_RMj)
qui replace TSS_RM=TSS_RM^2
qui egen ESS_RMj=sd(phat) if Male==1
qui egen ESS_RM=max(ESS_RMj)
qui replace ESS_RM=ESS_RM^2
qui gen R2_RM=ESS_RM/TSS_RM
qui drop  phat- alpha 

qui ge PartialM= R2_PM- R2_RM
qui ge PartialF= R2_PF- R2_RF
qui ge DPartial=(R2_PF-R2_RF)-(R2_PM-R2_RM)

qui ge nn=_n
qui keep if nn==1
qui keep R2*
qui ge PartialM= R2_PM- R2_RM
qui ge PartialF= R2_PF- R2_RF
qui ge DPartial=(R2_PF-R2_RF)-(R2_PM-R2_RM)
qui ge Partial= R2_P- R2_R
qui append using "$data\bsresults_r.dta" 
qui save "$data\bsresults_r.dta", replace
}

su


*****************************************************************************************************************************************
* Bar plot with CIs (Figuer 4)
*****************************************************************************************************************************************

use "$data\GenderLuckData_var.dta",clear
est restore es2

* Women
predictnl effortwon_1=_b[_cons]+_b[L.WinnerPrize]*.1 /*A*/
predictnl effortlost_1=_b[_cons]+_b[L.Loser]+_b[L.Loserv]*.1 /*B*/
predictnl effortwon_2=_b[_cons]+_b[L.WinnerPrize]*3.9 /*C*/
predictnl effortlost_2=_b[_cons]+_b[L.Loser]+_b[L.Loserv]*3.9 /*D*/

* Men
predictnl effortwon_3=_b[_cons]+_b[Male]+_b[L.WinnerPrize]*.1+_b[L.WinnerPrizemale]*.1 /*A*/
predictnl effortlost_3=_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*.1+_b[L.Loservmale]*.1 /*B*/
predictnl effortwon_4=_b[_cons]+_b[Male]+_b[L.WinnerPrize]*3.9+_b[L.WinnerPrizemale]*3.9 /*C*/
predictnl effortlost_4=_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*3.9+_b[L.Loservmale]*3.9 /*D*/

predictnl D1=(_b[_cons]+_b[L.WinnerPrize]*.1)-(_b[_cons]+_b[L.Loser]+_b[L.Loserv]*.1), se(Dse1)
predictnl D2=(_b[_cons]+_b[L.WinnerPrize]*.1)-(_b[_cons]+_b[L.WinnerPrize]*3.9), se(Dse2)
predictnl D3=(_b[_cons]+_b[L.Loser]+_b[L.Loserv]*.1)-(_b[_cons]+_b[L.Loser]+_b[L.Loserv]*3.9), se(Dse3)
predictnl D4=(_b[_cons]+_b[L.WinnerPrize]*3.9)-(_b[_cons]+_b[L.Loser]+_b[L.Loserv]*3.9), se(Dse4)

predictnl E1=(_b[_cons]+_b[Male]+_b[L.WinnerPrize]*.1+_b[L.WinnerPrizemale]*.1)-(_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*.1+_b[L.Loservmale]*.1), se(Ese1)
predictnl E2=(_b[_cons]+_b[Male]+_b[L.WinnerPrize]*.1+_b[L.WinnerPrizemale]*.1)-(_b[_cons]+_b[Male]+_b[L.WinnerPrize]*3.9+_b[L.WinnerPrizemale]*3.9), se(Ese2)
predictnl E3=(_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*.1+_b[L.Loservmale]*.1)-(_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*3.9+_b[L.Loservmale]*3.9), se(Ese3)
predictnl E4=(_b[_cons]+_b[Male]+_b[L.WinnerPrize]*3.9+_b[L.WinnerPrizemale]*3.9)-(_b[_cons]+_b[Male]+_b[L.Loser]+_b[L.Losermale]+_b[L.Loserv]*3.9+_b[L.Loservmale]*3.9), se(Ese4)

keep effortwon_1- effortlost_4 D* E*
keep if _n==1
ge i=1
reshape long effortwon_ effortlost_ D Dse E Ese, i(i) 
ge j=_j
ge prize=.1 if j==1|j==3
replace prize=3.9 if j==2|j==4
ge Male=1 if j==3|j==4
replace Male=0 if j==1|j==2
ge uciD=1.96*Dse+D
ge lciD=-1.96*Dse+D
ge uciE=1.96*Ese+E
ge lciE=-1.96*Ese+E
save "$data\dataplots1.dta", replace


use "$data\dataplots1.dta", clear
ge prize1=prize/1.5
ge prize2=prize1+1

* Women
twoway (bar effortwon_ prize1 if Male==0, color(gs0))  /*
*/ (bar effortlost_ prize2 if Male==0,color(gs16) lcolor(black) lwidth(.5)) , /*
*/ aspectratio(.7)/*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ ytitle("Effort in current round",size(large))/*
*/ ylabel(24(2)30, labsize(large))/*
*/ xlabel(.5 `""Prize in previous" "round: 0.10""' 3`""Prize in previous" "round: 3.90""',noticks labsize(large))/*
*/ xtick()/*
*/  text(24.6 -.1 "A", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 .9 "B", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 2.45 "C", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 3.4 "D", place(e) color(black) box bcolor(white) size(8))/*
*/ legend( label(1 "Won in previous round") label(2 "Lost in previous round") size(large) cols(1)) 

twoway (bar D j, color(gs16) lcolor(black) lwidth(.5) barw(.7)) (rcap uciD lciD j, color(gs0)),/*
*/ aspectratio(.7)/*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ xtitle("")/*
*/ yline(0)/*
*/ ylabel(-5(5)10, labsize(large))/*
*/ ytitle("Difference in effort",size(large))/*
*/ xlabel(1 `"A-B"' 2 `"A-C"' 3 `"B-D"' 4 `"C-D"',noticks labsize(large))/*
*/ xtick() /*
*/ legend(off)

* Men
twoway (bar effortwon_ prize1 if Male==1, color(gs0))  /*
*/ (bar effortlost_ prize2 if Male==1,color(gs16) lcolor(black) lwidth(.5)) , /*
*/ aspectratio(.7)/*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ ytitle("Effort in current round",size(large))/*
*/ ylabel(24(2)30, labsize(large))/*
*/ xlabel(.5 `""Prize in previous" "round: 0.10""' 3`""Prize in previous" "round: 3.90""',noticks labsize(large))/*
*/ xtick()/*
*/  text(24.6 -.1 "A", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 .9 "B", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 2.45 "C", place(e) color(black) box bcolor(white) size(8))/*
*/  text(24.6 3.4 "D", place(e) color(black) box bcolor(white) size(8))/*
*/ legend( label(1 "Won in previous round") label(2 "Lost in previous round") size(large) cols(1)) 

twoway (bar E j, color(gs16) lcolor(black) lwidth(.5) barw(.7)) (rcap uciE lciE j, color(gs0)),/*
*/ aspectratio(.7)/*
*/ legend(region(lstyle(none)))/*
*/ plotregion(lstyle(none))/*
*/ xtitle("")/*
*/ yline(0)/*
*/ ylabel(-5(5)10, labsize(large))/*
*/ ytitle("Difference in effort",size(large))/*
*/ xlabel(1 `"A-B"' 2 `"A-C"' 3 `"B-D"' 4 `"C-D"',noticks labsize(large))/*
*/ xtick() /*
*/ legend(off)

***********************************************************************************************
* Appendix Robustness - Table 3
* Robustness to choice of instruments and number of lags
***********************************************************************************************

use "$data\GenderLuckData_var.dta",clear

* R1
* Drop Effort (t-2)
xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/gmmstyle(Effort Effortmale, lag(3 3) equation(diff) col)/*
*/ rob cluster(Sub)
estimates store es_R1
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
drop consmale semale

* R2
* Drop all effort reg
xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_R2
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
drop consmale semale

* R3
xtabond2 Effort Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 2) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_R3
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
drop consmale semale

* R4
xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/3).Loserfemale l(1/3).Losermale l(1/3).WinnerPrizefemale l(1/3).WinnerPrizemale l(1/3).Loservfemale l(1/3).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 4) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 4) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_R4
test L3.Loserm==l3.WinnerPrizemale==l3.Loservmale==0==L3.Loserf==l3.WinnerPrizefemale==l3.Loservfemale
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
drop consmale semale

***********************************************************************************************
* Appendix Robustness - Table 4
***********************************************************************************************

use "$data\GenderLuckData_var.dta",clear

***********************************************************************************************
* P1 Add inta-period disappointment a la Gill and Prowse (2012)
***********************************************************************************************

* Robustness to Disappointment
* 2nd movers
xtabond2 Effort i OtherEffort Male prize prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale  l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(i OtherEffort  prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es2_mf_r1
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale


***********************************************************************************************
* P2 Add biggest win and biggest loss
***********************************************************************************************

ge Winnerprize=Winner*prize

ge BigWin=Winnerprize if Period==1
forvalues j=2/10{
replace BigWin=l.BigWin if Period==`j' & Winnerprize<=l.BigWin
replace BigWin=Winnerprize if Period==`j' & Winnerprize>l.BigWin
}
ge BigWinMale=BigWin*Male
ge BigWinFemale=BigWin*(1-Male)

ge Lossprize=(1-Winner)*prize

ge BigLoss=Lossprize if Period==1
forvalues j=2/10{
replace BigLoss=l.BigLoss if Period==`j' & Lossprize<=l.BigLoss
replace BigLoss=Lossprize if Period==`j' & Lossprize>l.BigLoss
}
ge BigLossMale=BigLoss*Male
ge BigLossFemale=BigLoss*(1-Male)

xtabond2 Effort Male prizefemale prizemale TTM* TTF* l.BigWinFemale l.BigWinMale l.BigLossFemale l.BigLossMale l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_mf_BigWinBigLoss
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale

xtabond2 Effort Male prize prizemale TTM* TTF* l.BigWin l.BigWinMale l.BigLoss l.BigLossMale l(1/2).Loser l(1/2).Losermale l(1/2).WinnerPrize l(1/2).WinnerPrizemale l(1/2).Loserv l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
est store es_BigWinBigLoss


***********************************************************************************************
* P3 Add number of previous wins 
***********************************************************************************************

bys Subject: gen NWin=sum(Winner)
ge NWinMale=NWin*Male
ge NWinFemale=NWin*(1-Male)

xtabond2 Effort Male prizefemale prizemale TTM* TTF* l.NWinFemale l.NWinMale l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_mf_NWin
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale

xtabond2 Effort Male prize prizemale TTM* TTF* l.NWin l.NWinMale l(1/2).Loser l(1/2).Losermale l(1/2).WinnerPrize l(1/2).WinnerPrizemale l(1/2).Loserv l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
est store es_NWin

***********************************************************************************************
* P4 Add total winnings and total losses todate
***********************************************************************************************

bys Subject: ge CumWinnings=sum(Winnerprize)
bys Subject: ge CumLosses=sum(Lossprize)


ge CumWinningsMale=CumWinnings*Male
ge CumWinningsFemale=CumWinnings*(1-Male)

ge CumLossesMale=CumLosses*Male
ge CumLossesFemale=CumLosses*(1-Male)

xtabond2 Effort Male prizefemale prizemale TTM* TTF* l.CumWinningsMale l.CumWinningsFemale l.CumLossesMale  l.CumLossesFemale l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es_mf_CumWinLoss
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale

xtabond2 Effort Male prize prizemale TTM* TTF* l.CumWinnings l.CumWinningsMale l.CumLosses  l.CumLossesMale l(1/2).Loser l(1/2).Losermale l(1/2).WinnerPrize l(1/2).WinnerPrizemale l(1/2).Loserv l(1/2).Loservmale if Type==2, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
est store es_CumWinLoss


***********************************************************************************************
* Table of Robustness results (Table 4 in Appendix)
***********************************************************************************************

estimates table es2_mf_r1 es_mf_BigWinBigLoss es_mf_NWin  es_mf_CumWinLoss, se  t(%9.0g) stats(N N_g hansen hansen_df hansenp ar1 ar1p ar2 ar2p)

***********************************************************************************************
* Appendix Table 4 
* Pref Spec: 1st movers
***********************************************************************************************

* 1st mover
xtabond2 Effort  Male prizefemale prizemale TTM* TTF* l(1/2).Loserfemale l(1/2).Losermale l(1/2).WinnerPrizefemale l(1/2).WinnerPrizemale l(1/2).Loservfemale l(1/2).Loservmale if Type==1, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
estimates store es2_mf_1
predictnl consmale= _b[_cons]+_b[Male] , se(semale)
su  consmale semale
drop consmale semale

xtabond2 Effort Male prize prizemale TTM* TTF* l(1/2).Loser l(1/2).Losermale l(1/2).WinnerPrize l(1/2).WinnerPrizemale l(1/2).Loserv l(1/2).Loservmale if Type==1, ivstyle(prize prizemale TT*, equ(diff))/*
*/gmmstyle(RU RUmale RUprize RUprizemale prize prizemale OtherEffort OtherEffortmale, lag(1 3) equation(diff) col)/*
*/gmmstyle(Effort Effortmale, lag(2 3) equation(diff) col)/*
*/ivstyle(Male, equ(level))/*
*/ rob cluster(Sub)
est store es2_1



*************************************************************************************
* Appendix : Table 6 
*************************************************************************************

use "$data\GenderLuckData_var.dta",clear
matrix table=[1,1,1,1]
matrix tableN=[1,1,1,1]
forvalues j=0/1{
forvalues k=0/1{
forvalues v=1/4{
su Effort if Type==1 & Male==`j' & L.Winner==`k' & l.prize>=(`v'-1) & l.prize<(`v')
scalar junk = r(mean)
matrix table =[table,junk]
su Effort if Type==1 & Male==`j' & L.Winner==`k' & l.prize>=(`v'-1) & l.prize<(`v')
scalar junk = r(N)
matrix tableN =[tableN,junk]
}
}
}
mata
table=st_matrix("table")
tableN=st_matrix("tableN")
table=colshape(table,4)
tableN=colshape(tableN,4)
st_matrix("table",table)
st_matrix("tableN",tableN)
end
matrix table=table'
matrix tableN=tableN'
matrix list table 
matrix list tableN

matrix table=[1,1,1,1]
matrix tableN=[1,1,1,1]
forvalues j=0/1{
forvalues k=0/1{
forvalues v=1/4{
su Effort if Type==2 & Male==`j' & L.Winner==`k' & l.prize>=(`v'-1) & l.prize<(`v')
scalar junk = r(mean)
matrix table =[table,junk]
su Effort if Type==2 & Male==`j' & L.Winner==`k' & l.prize>=(`v'-1) & l.prize<(`v')
scalar junk = r(N)
matrix tableN =[tableN,junk]
}
}
}
mata
table=st_matrix("table")
tableN=st_matrix("tableN")
table=colshape(table,4)
tableN=colshape(tableN,4)
st_matrix("table",table)
st_matrix("tableN",tableN)
end
matrix table=table'
matrix tableN=tableN'
matrix list table 
matrix list tableN

* cleanup
erase "$data\GenderLuckData_var.dta"
erase "$data\male.dta"
erase "$data\dataplots1.dta"
erase "$data\bsresults.dta"
erase "$data\bsresults_r.dta"
erase "$data\bsdata.dta"
erase "$data\bs_desc.dta"
erase "$data\bs_desc1.dta"
